import { createRouter, createWebHistory } from 'vue-router';
import store from '@/stores/counter';
import axios from 'axios';
import common from './module/common';
import admin from './module/admin';
import institution from './module/institution';
import personal from './module/personal';
import frameCommon from './module/frameCommon';

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    ...common,
    {
      path: '/',
      redirect: '/login'
    },
    {
      path: '/login',
      name: 'login',
      meta: { title: '中科在线(长春)-吉林专利市场' },
      component: () => import('@/views/login/index.vue')
    },
    {
      path: '/homeIndex',
      meta: { title: '中科在线(长春)-吉林专利市场' },
      component: () => import('@common/src/components/patent-frame/home.vue'),
      children: [
        {
          path: '/homeIndex',
          meta: { title: '中科在线(长春)-吉林专利市场' },
          component: () => import('@/views/home/index.vue')
        },
        // 管理员
        ...admin,
        // 机构
        ...institution,
        // 个人
        ...personal,
        // 公共
        ...frameCommon
      ]
    }
  ]
});
router.beforeEach(async (to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = localStorage.getItem('token');
  if (to.name != 'login') {
    if (token) {
      const res = await axios.request({
        method: 'get',
        url: '/zkzx/v2/api/token/tokenView',
        responseType: 'json',
        headers: {
          token: token
        }
      });
      if (res.data.errcode == '0') {
        store.commit('setUser', res.data.data, { root: true });
      }
      next();
    } else next('/login');
  } else next();
});

export default router;
